@@ -16,8 +16,8 @@ BABYBLUE = 36  # 浅蓝色
 GREY = 37  # 灰色
 FrenchGREY = 38  # 浅灰色
 
-PRINT_COLOR = BLUE
-BG_COLOR = GREEN
+PRINT_COLOR = RED
+BG_COLOR = BLUE + 10
 
 default_config = {
     'level': 'INFO',
